@@ -1378,6 +1378,10 @@ class AsdfFile:
         """
         Get a nested dictionary of the schema information for a given key, relative to the path.
 
+        This method will only return unambiguous info. If a property is subject to multiple
+        subschemas or contains ambiguous entries (multiple titles) no result will be returned
+        for that property.
+
         Parameters
         ----------
         key : str
@@ -1408,6 +1412,7 @@ class AsdfFile:
             self.tree,
             preserve_list=preserve_list,
             refresh_extension_manager=refresh_extension_manager,
+            extension_manager=self.extension_manager,
         )
 
     def info(
@@ -1448,6 +1453,7 @@ class AsdfFile:
             show_values=show_values,
             identifier="root",
             refresh_extension_manager=refresh_extension_manager,
+            extension_manager=self.extension_manager,
         )
         print("\n".join(lines))
 
