@@ -1,9 +1,11 @@
+import importlib.resources
+
 import pytest
 
 from asdf import config, schema
 
 from . import create_large_tree, create_small_tree
-from .httpserver import HTTPServer, RangeHTTPServer
+from .httpserver import HTTPServer
 
 
 @pytest.fixture()
@@ -51,16 +53,12 @@ def httpserver(request):
 
 
 @pytest.fixture()
-def rhttpserver(request):
-    """
-    The returned ``httpserver`` provides a threaded HTTP server
-    instance.  It serves content from a temporary directory (available
-    as the attribute tmpdir) at randomly assigned URL (available as
-    the attribute url).  The server supports HTTP Range headers.
+def test_data_path():
+    return importlib.resources.files("asdf") / "_tests" / "data"
 
-    * ``tmpdir`` - path to the tmpdir that it's serving from (str)
-    * ``url`` - the base url for the server
-    """
-    server = RangeHTTPServer()
-    yield server
-    server.finalize()
+
+@pytest.fixture(params=[True, False], ids=["lazy", "not-lazy"])
+def with_lazy_tree(request):
+    with config.config_context() as cfg:
+        cfg.lazy_tree = request.param
+        yield
