@@ -75,7 +75,7 @@ def with_custom_extension():
             {
                 "http://nowhere.org/schemas/custom/datatype-1.0.0": """%YAML 1.1
 ---
-$schema: "http://stsci.edu/schemas/asdf/asdf-schema-1.0.0"
+$schema: "http://stsci.edu/schemas/asdf/asdf-schema-1.1.0"
 id: "http://nowhere.org/schemas/custom/datatype-1.0.0"
 type: object
 properties:
@@ -102,7 +102,7 @@ properties:
     exact_datatype: true""",
                 "http://nowhere.org/schemas/custom/ndim-1.0.0": """%YAML 1.1
 ---
-$schema: "http://stsci.edu/schemas/asdf/asdf-schema-1.0.0"
+$schema: "http://stsci.edu/schemas/asdf/asdf-schema-1.1.0"
 id: "http://nowhere.org/schemas/custom/ndim-1.0.0"
 type: object
 properties:
@@ -282,7 +282,7 @@ def test_array_inline_threshold_recursive(tmp_path):
 
 def test_copy_inline():
     yaml = """
-x0: !core/ndarray-1.0.0
+x0: !core/ndarray-1.1.0
   data: [-1.0, 1.0]
     """
 
@@ -371,7 +371,7 @@ def test_inline():
 
 
 def test_inline_bare():
-    content = "arr: !core/ndarray-1.0.0 [[1, 2, 3, 4], [5, 6, 7, 8]]"
+    content = "arr: !core/ndarray-1.1.0 [[1, 2, 3, 4], [5, 6, 7, 8]]"
     buff = helpers.yaml_to_asdf(content)
 
     with asdf.open(buff) as ff:
@@ -413,7 +413,7 @@ def test_len_roundtrip(tmp_path):
 
 def test_mask_arbitrary():
     content = """
-arr: !core/ndarray-1.0.0
+arr: !core/ndarray-1.1.0
   data: [[1, 2, 3, 1234], [5, 6, 7, 8]]
   mask: 1234
     """
@@ -425,7 +425,7 @@ arr: !core/ndarray-1.0.0
 
 def test_mask_nan():
     content = """
-arr: !core/ndarray-1.0.0
+arr: !core/ndarray-1.1.0
   data: [[1, 2, 3, .NaN], [5, 6, 7, 8]]
   mask: .NaN
     """
@@ -455,7 +455,7 @@ def test_string_table(tmp_path):
 
 
 def test_inline_string():
-    content = "arr: !core/ndarray-1.0.0 ['a', 'b', 'c']"
+    content = "arr: !core/ndarray-1.1.0 ['a', 'b', 'c']"
     buff = helpers.yaml_to_asdf(content)
 
     with asdf.open(buff) as ff:
@@ -464,7 +464,7 @@ def test_inline_string():
 
 def test_inline_structured():
     content = """
-arr: !core/ndarray-1.0.0
+arr: !core/ndarray-1.1.0
     datatype: [['ascii', 4], uint16, uint16, ['ascii', 4]]
     data: [[M110, 110, 205, And],
            [ M31,  31, 224, And],
@@ -622,10 +622,10 @@ def test_operations_on_ndarray_proxies(tmp_path):
 
 def test_mask_datatype(tmp_path):
     content = """
-arr: !core/ndarray-1.0.0
+arr: !core/ndarray-1.1.0
     data: [1, 2, 3]
     dtype: int32
-    mask: !core/ndarray-1.0.0
+    mask: !core/ndarray-1.1.0
         data: [true, true, false]
     """
     buff = helpers.yaml_to_asdf(content)
@@ -636,10 +636,10 @@ arr: !core/ndarray-1.0.0
 
 def test_invalid_mask_datatype(tmp_path):
     content = """
-arr: !core/ndarray-1.0.0
+arr: !core/ndarray-1.1.0
     data: [1, 2, 3]
     dtype: int32
-    mask: !core/ndarray-1.0.0
+    mask: !core/ndarray-1.1.0
         data: ['a', 'b', 'c']
     """
     buff = helpers.yaml_to_asdf(content)
@@ -657,7 +657,7 @@ arr: !core/ndarray-1.0.0
 def test_ndim_validation(tmp_path):
     content = """
 obj: !<tag:nowhere.org:custom/ndim-1.0.0>
-    a: !core/ndarray-1.0.0
+    a: !core/ndarray-1.1.0
        data: [1, 2, 3]
     """
     buff = helpers.yaml_to_asdf(content)
@@ -672,7 +672,7 @@ obj: !<tag:nowhere.org:custom/ndim-1.0.0>
 
     content = """
 obj: !<tag:nowhere.org:custom/ndim-1.0.0>
-    a: !core/ndarray-1.0.0
+    a: !core/ndarray-1.1.0
        data: [[1, 2, 3]]
     """
     buff = helpers.yaml_to_asdf(content)
@@ -682,7 +682,7 @@ obj: !<tag:nowhere.org:custom/ndim-1.0.0>
 
     content = """
 obj: !<tag:nowhere.org:custom/ndim-1.0.0>
-    a: !core/ndarray-1.0.0
+    a: !core/ndarray-1.1.0
        shape: [1, 3]
        data: [[1, 2, 3]]
     """
@@ -693,7 +693,7 @@ obj: !<tag:nowhere.org:custom/ndim-1.0.0>
 
     content = """
 obj: !<tag:nowhere.org:custom/ndim-1.0.0>
-    b: !core/ndarray-1.0.0
+    b: !core/ndarray-1.1.0
        data: [1, 2, 3]
     """
     buff = helpers.yaml_to_asdf(content)
@@ -703,7 +703,7 @@ obj: !<tag:nowhere.org:custom/ndim-1.0.0>
 
     content = """
 obj: !<tag:nowhere.org:custom/ndim-1.0.0>
-    b: !core/ndarray-1.0.0
+    b: !core/ndarray-1.1.0
        data: [[1, 2, 3]]
     """
     buff = helpers.yaml_to_asdf(content)
@@ -713,7 +713,7 @@ obj: !<tag:nowhere.org:custom/ndim-1.0.0>
 
     content = """
 obj: !<tag:nowhere.org:custom/ndim-1.0.0>
-    b: !core/ndarray-1.0.0
+    b: !core/ndarray-1.1.0
        data: [[[1, 2, 3]]]
     """
     buff = helpers.yaml_to_asdf(content)
@@ -731,7 +731,7 @@ obj: !<tag:nowhere.org:custom/ndim-1.0.0>
 def test_datatype_validation(tmp_path):
     content = """
 obj: !<tag:nowhere.org:custom/datatype-1.0.0>
-    a: !core/ndarray-1.0.0
+    a: !core/ndarray-1.1.0
        data: [1, 2, 3]
        datatype: float32
     """
@@ -742,7 +742,7 @@ obj: !<tag:nowhere.org:custom/datatype-1.0.0>
 
     content = """
 obj: !<tag:nowhere.org:custom/datatype-1.0.0>
-    a: !core/ndarray-1.0.0
+    a: !core/ndarray-1.1.0
        data: [1, 2, 3]
        datatype: float64
     """
@@ -758,7 +758,7 @@ obj: !<tag:nowhere.org:custom/datatype-1.0.0>
 
     content = """
 obj: !<tag:nowhere.org:custom/datatype-1.0.0>
-    a: !core/ndarray-1.0.0
+    a: !core/ndarray-1.1.0
        data: [1, 2, 3]
        datatype: int16
     """
@@ -769,7 +769,7 @@ obj: !<tag:nowhere.org:custom/datatype-1.0.0>
 
     content = """
 obj: !<tag:nowhere.org:custom/datatype-1.0.0>
-    b: !core/ndarray-1.0.0
+    b: !core/ndarray-1.1.0
        data: [1, 2, 3]
        datatype: int16
     """
@@ -785,7 +785,7 @@ obj: !<tag:nowhere.org:custom/datatype-1.0.0>
 
     content = """
 obj: !<tag:nowhere.org:custom/datatype-1.0.0>
-    a: !core/ndarray-1.0.0
+    a: !core/ndarray-1.1.0
        data: [[1, 'a'], [2, 'b'], [3, 'c']]
        datatype:
          - name: a
@@ -808,7 +808,7 @@ obj: !<tag:nowhere.org:custom/datatype-1.0.0>
 def test_structured_datatype_validation(tmp_path):
     content = """
 obj: !<tag:nowhere.org:custom/datatype-1.0.0>
-    c: !core/ndarray-1.0.0
+    c: !core/ndarray-1.1.0
        data: [[1, 'a'], [2, 'b'], [3, 'c']]
        datatype:
          - name: a
@@ -823,7 +823,7 @@ obj: !<tag:nowhere.org:custom/datatype-1.0.0>
 
     content = """
 obj: !<tag:nowhere.org:custom/datatype-1.0.0>
-    c: !core/ndarray-1.0.0
+    c: !core/ndarray-1.1.0
        data: [[1, 'a'], [2, 'b'], [3, 'c']]
        datatype:
          - name: a
@@ -843,7 +843,7 @@ obj: !<tag:nowhere.org:custom/datatype-1.0.0>
 
     content = """
 obj: !<tag:nowhere.org:custom/datatype-1.0.0>
-    c: !core/ndarray-1.0.0
+    c: !core/ndarray-1.1.0
        data: [[1, 'a', 0], [2, 'b', 1], [3, 'c', 2]]
        datatype:
          - name: a
@@ -865,7 +865,7 @@ obj: !<tag:nowhere.org:custom/datatype-1.0.0>
 
     content = """
 obj: !<tag:nowhere.org:custom/datatype-1.0.0>
-    c: !core/ndarray-1.0.0
+    c: !core/ndarray-1.1.0
        data: [1, 2, 3]
     """
     buff = helpers.yaml_to_asdf(content)
@@ -880,7 +880,7 @@ obj: !<tag:nowhere.org:custom/datatype-1.0.0>
 
     content = """
 obj: !<tag:nowhere.org:custom/datatype-1.0.0>
-    d: !core/ndarray-1.0.0
+    d: !core/ndarray-1.1.0
        data: [[1, 'a'], [2, 'b'], [3, 'c']]
        datatype:
          - name: a
@@ -900,7 +900,7 @@ obj: !<tag:nowhere.org:custom/datatype-1.0.0>
 
     content = """
 obj: !<tag:nowhere.org:custom/datatype-1.0.0>
-    d: !core/ndarray-1.0.0
+    d: !core/ndarray-1.1.0
        data: [[1, 'a'], [2, 'b'], [3, 'c']]
        datatype:
          - name: a
@@ -924,7 +924,7 @@ def test_string_inline():
 
 def test_inline_shape_mismatch():
     content = """
-arr: !core/ndarray-1.0.0
+arr: !core/ndarray-1.1.0
   data: [1, 2, 3]
   shape: [2]
     """
@@ -976,20 +976,20 @@ def test_memmap_write(tmp_path):
     tmpfile = str(tmp_path / "data.asdf")
     tree = {"data": np.zeros(100)}
 
-    with asdf.AsdfFile(tree) as af:
+    with asdf.AsdfFile(tree, memmap=False) as af:
         # Make sure we're actually writing to an internal array for this test
         af.write_to(tmpfile, all_array_storage="internal")
 
-    with asdf.open(tmpfile, mode="rw", copy_arrays=False) as af:
+    with asdf.open(tmpfile, mode="rw", memmap=True) as af:
         data = af["data"]
         assert data.flags.writeable is True
         data[0] = 42
         assert data[0] == 42
 
-    with asdf.open(tmpfile, mode="rw", copy_arrays=False) as af:
+    with asdf.open(tmpfile, mode="rw", memmap=True) as af:
         assert af["data"][0] == 42
 
-    with asdf.open(tmpfile, mode="r", copy_arrays=False) as af:
+    with asdf.open(tmpfile, mode="r", memmap=True) as af:
         assert af["data"][0] == 42
 
 
@@ -1002,13 +1002,13 @@ def test_readonly(tmp_path):
         af.write_to(tmpfile, all_array_storage="internal")
 
     # Opening in read mode (the default) should mean array is readonly
-    with asdf.open(tmpfile) as af:
+    with asdf.open(tmpfile, memmap=True) as af:
         assert af["data"].flags.writeable is False
         with pytest.raises(ValueError, match=r"assignment destination is read-only"):
             af["data"][0] = 41
 
     # Forcing memmap, the array should still be readonly
-    with asdf.open(tmpfile, copy_arrays=False) as af:
+    with asdf.open(tmpfile, memmap=True) as af:
         assert af["data"].flags.writeable is False
         with pytest.raises(ValueError, match=r"assignment destination is read-only"):
             af["data"][0] = 41
@@ -1019,7 +1019,7 @@ def test_readonly(tmp_path):
         af["data"][0] = 40
 
     # Copying the arrays makes it safe to write to the underlying array
-    with asdf.open(tmpfile, mode="r", copy_arrays=True) as af:
+    with asdf.open(tmpfile, mode="r", memmap=False) as af:
         assert af["data"].flags.writeable is True
         af["data"][0] = 42
 
@@ -1046,7 +1046,7 @@ def test_block_data_change(pad_blocks, tmp_path):
     with asdf.AsdfFile(tree) as af:
         af.write_to(tmpfile, pad_blocks=pad_blocks)
 
-    with asdf.open(tmpfile, mode="rw") as af:
+    with asdf.open(tmpfile, mode="rw", memmap=True) as af:
         assert np.all(af.tree["data"] == 0)
         array_before = af.tree["data"].__array__()
         af.tree["data"][:5] = 1
