@@ -1,23 +1,11 @@
 import contextlib
 import io
-import warnings
 
 import numpy as np
 import pytest
 
 import asdf
 from asdf import generic_io, util
-from asdf.exceptions import AsdfDeprecationWarning
-
-
-def test_is_primitive():
-    with warnings.catch_warnings():
-        warnings.filterwarnings("ignore", "asdf.util.is_primitive is deprecated", AsdfDeprecationWarning)
-        for value in [None, "foo", 1, 1.39, 1 + 1j, True]:
-            assert util.is_primitive(value) is True
-
-        for value in [[], (), {}, set()]:
-            assert util.is_primitive(value) is False
 
 
 def test_not_set():
@@ -104,25 +92,6 @@ def test_get_file_type(content, expected_type):
     assert fd.read() == content
 
 
-def test_minversion():
-    import numpy as np
-    import yaml
-
-    good_versions = ["1.16", "1.16.1", "1.16.0.dev", "1.16dev"]
-    bad_versions = ["100000", "100000.2rc1"]
-    with warnings.catch_warnings():
-        warnings.filterwarnings("ignore", "asdf.util.minversion", AsdfDeprecationWarning)
-        for version in good_versions:
-            assert util.minversion(np, version)
-            assert util.minversion("numpy", version)
-        for version in bad_versions:
-            assert not util.minversion(np, version)
-            assert not util.minversion("numpy", version)
-
-        assert util.minversion(yaml, "3.1")
-        assert util.minversion("yaml", "3.1")
-
-
 @pytest.mark.parametrize("input_type", ["filename", "binary_file", "generic_file"])
 @pytest.mark.parametrize("tagged", [True, False])
 def test_load_yaml(tmp_path, input_type, tagged):
@@ -145,3 +114,17 @@ def test_load_yaml(tmp_path, input_type, tagged):
         assert isinstance(tree["a"], asdf.tagged.TaggedDict)
     else:
         assert not isinstance(tree["a"], asdf.tagged.TaggedDict)
+
+
+@pytest.mark.parametrize("tagged", [True, False])
+def test_load_yaml_recursion(tmp_path, tagged):
+    fn = tmp_path / "test.asdf"
+    tree = {}
+    tree["d"] = {}
+    tree["d"]["d"] = tree["d"]
+    tree["l"] = []
+    tree["l"].append(tree["l"])
+    asdf.AsdfFile(tree).write_to(fn)
+    tree = util.load_yaml(fn, tagged=tagged)
+    assert tree["d"]["d"] is tree["d"]
+    assert tree["l"][0] is tree["l"]
