@@ -2,7 +2,8 @@
 Commands for displaying summaries of ASDF trees
 """
 
-from .. import _convenience as convenience
+import asdf
+
 from .main import Command
 
 __all__ = ["info"]
@@ -12,7 +13,9 @@ class Info(Command):
     @classmethod
     def setup_arguments(cls, subparsers):
         parser = subparsers.add_parser(
-            "info", help="Print a rendering of an ASDF tree.", description="Print a rendering of an ASDF tree."
+            "info",
+            help="Print a rendering of an ASDF tree.",
+            description="Print a rendering of an ASDF tree.",
         )
 
         parser.add_argument("filename", help="ASDF file to render")
@@ -33,4 +36,5 @@ class Info(Command):
 
 
 def info(filename, max_rows, max_cols, show_values):
-    convenience.info(filename, max_rows=max_rows, max_cols=max_cols, show_values=show_values)
+    with asdf.open(filename) as af:
+        af.info(max_rows, max_cols, show_values)
