@@ -3,11 +3,9 @@ Utility functions for managing tree-like data structures.
 """
 
 import types
-import warnings
 from contextlib import contextmanager
 
-from . import tagged
-from .exceptions import AsdfWarning
+from . import lazy_nodes, tagged
 
 __all__ = ["walk", "iter_tree", "walk_and_modify", "get_children", "is_container", "PendingValue", "RemoveNode"]
 
@@ -65,12 +63,12 @@ def iter_tree(top):
         if tree_id in seen:
             return
 
-        if isinstance(tree, (list, tuple)):
+        if isinstance(tree, (list, tuple, lazy_nodes.AsdfListNode)):
             seen.add(tree_id)
             for val in tree:
                 yield from recurse(val)
             seen.remove(tree_id)
-        elif isinstance(tree, dict):
+        elif isinstance(tree, (dict, lazy_nodes.AsdfDictNode)):
             seen.add(tree_id)
             for val in tree.values():
                 yield from recurse(val)
@@ -220,7 +218,7 @@ class _RemoveNode:
 RemoveNode = _RemoveNode()
 
 
-def walk_and_modify(top, callback, ignore_implicit_conversion=False, postorder=True, _context=None):
+def walk_and_modify(top, callback, postorder=True, _context=None):
     """Modify a tree by walking it with a callback function.  It also has
     the effect of doing a deep copy.
 
@@ -252,13 +250,6 @@ def walk_and_modify(top, callback, ignore_implicit_conversion=False, postorder=T
         before their parents.  If `False`, the callable is invoked on the
         parents first.  Defaults to `True`.
 
-    ignore_implicit_conversion : bool
-        Controls whether warnings should be issued when implicitly converting a
-        given type instance in the tree into a serializable object. The primary
-        case for this is currently ``namedtuple``.
-
-        Defaults to `False`.
-
     Returns
     -------
     tree : object
@@ -287,7 +278,10 @@ def walk_and_modify(top, callback, ignore_implicit_conversion=False, postorder=T
         return _handle_generator(result)
 
     def _handle_mapping(node, json_id):
-        result = node.__class__()
+        if isinstance(node, lazy_nodes.AsdfDictNode):
+            result = {}
+        else:
+            result = node.__class__()
         if isinstance(node, tagged.Tagged):
             result._tag = node._tag
 
@@ -318,7 +312,10 @@ def walk_and_modify(top, callback, ignore_implicit_conversion=False, postorder=T
                     del result[key]
 
     def _handle_mutable_sequence(node, json_id):
-        result = node.__class__()
+        if isinstance(node, lazy_nodes.AsdfListNode):
+            result = []
+        else:
+            result = node.__class__()
         if isinstance(node, tagged.Tagged):
             result._tag = node._tag
 
@@ -348,26 +345,20 @@ def walk_and_modify(top, callback, ignore_implicit_conversion=False, postorder=T
         # to yield here.
         contents = [_recurse(value, json_id) for value in node]
 
-        try:
-            result = node.__class__(contents)
-            if isinstance(node, tagged.Tagged):
-                result._tag = node._tag
-        except TypeError:
-            # The derived class signature is different, so simply store the
-            # list representing the contents. Currently this is primarily
-            # intended to handle namedtuple and NamedTuple instances.
-            if not ignore_implicit_conversion:
-                warnings.warn(f"Failed to serialize instance of {type(node)}, converting to list instead", AsdfWarning)
-            result = contents
+        result = node.__class__(contents)
+        if isinstance(node, tagged.Tagged):
+            result._tag = node._tag
 
         return result
 
     def _handle_children(node, json_id):
-        if isinstance(node, dict):
+        if isinstance(node, (dict, lazy_nodes.AsdfDictNode)):
             result = _handle_mapping(node, json_id)
-        elif isinstance(node, tuple):
+        # don't treat namedtuple instances as tuples
+        # see: https://github.com/python/cpython/issues/52044
+        elif isinstance(node, tuple) and not hasattr(node, "_fields"):
             result = _handle_immutable_sequence(node, json_id)
-        elif isinstance(node, list):
+        elif isinstance(node, (list, lazy_nodes.AsdfListNode)):
             result = _handle_mutable_sequence(node, json_id)
         else:
             result = node
@@ -390,7 +381,7 @@ def walk_and_modify(top, callback, ignore_implicit_conversion=False, postorder=T
             # URIs.  Ignore an id that is not a string, since it may
             # be an object defining an id property and not an id
             # itself (this is common in metaschemas).
-            if isinstance(node, dict) and "id" in node and isinstance(node["id"], str):
+            if isinstance(node, (dict, lazy_nodes.AsdfDictNode)) and "id" in node and isinstance(node["id"], str):
                 json_id = node["id"]
 
             if postorder:
@@ -437,10 +428,10 @@ def get_children(node):
         node has no children (either it is an empty container, or is
         a non-container type)
     """
-    if isinstance(node, dict):
+    if isinstance(node, (dict, lazy_nodes.AsdfDictNode)):
         return list(node.items())
 
-    if isinstance(node, (list, tuple)):
+    if isinstance(node, (list, tuple, lazy_nodes.AsdfListNode)):
         return list(enumerate(node))
 
     return []
@@ -461,4 +452,4 @@ def is_container(node):
     bool
         True if node is a container, False otherwise
     """
-    return isinstance(node, (dict, list, tuple))
+    return isinstance(node, (dict, list, tuple, lazy_nodes.AsdfDictNode, lazy_nodes.AsdfListNode))
