@@ -11,7 +11,7 @@ from semantic_version import SimpleSpec, Version
 _yaml_base_loader = yaml.CSafeLoader if getattr(yaml, "__with_libyaml__", None) else yaml.SafeLoader
 
 
-__all__ = ["AsdfVersion", "AsdfSpec", "AsdfVersionMixin", "split_tag_version", "join_tag_version"]
+__all__ = ["AsdfVersion", "AsdfVersionMixin", "split_tag_version", "join_tag_version"]
 
 
 def split_tag_version(tag):
@@ -30,34 +30,6 @@ def join_tag_version(name, version):
     return f"{name}-{version}"
 
 
-_version_map = {}
-
-
-def get_version_map(version):
-    version_map = _version_map.get(version)
-
-    if version_map is None:
-        from .config import get_config
-
-        uri = f"http://stsci.edu/schemas/asdf/version_map-{version}"
-        # The following call to yaml.load is safe because we're
-        # using a loader that inherits from pyyaml's SafeLoader.
-        version_map = yaml.load(get_config().resource_manager[uri], Loader=_yaml_base_loader)  # noqa: S506
-
-        # Separate the core tags from the rest of the standard for convenience
-        version_map["core"] = {}
-        version_map["standard"] = {}
-        for tag_name, tag_version in version_map["tags"].items():
-            if tag_name.startswith("tag:stsci.edu:asdf/core"):
-                version_map["core"][tag_name] = tag_version
-            else:
-                version_map["standard"][tag_name] = tag_version
-
-        _version_map[version] = version_map
-
-    return version_map
-
-
 @total_ordering
 class AsdfVersionMixin:
     """This mix-in is required in order to impose the total ordering that we
@@ -111,38 +83,6 @@ class AsdfVersion(AsdfVersionMixin, Version):
         super().__init__(version)
 
 
-class AsdfSpec(SimpleSpec):
-    def __init__(self, *args, **kwargs):
-        super().__init__(*args, **kwargs)
-
-    def match(self, version):
-        if isinstance(version, (str, tuple, list)):
-            version = AsdfVersion(version)
-        return super().match(version)
-
-    def __iterate_versions(self, versions):
-        for v in versions:
-            yield AsdfVersion(v) if isinstance(v, (str, tuple, list)) else v
-
-    def select(self, versions):
-        return super().select(self.__iterate_versions(versions))
-
-    def filter(self, versions):
-        return super().filter(self.__iterate_versions(versions))
-
-    def __eq__(self, other):
-        """Equality between Spec and Version, string, or tuple, means match"""
-        if isinstance(other, SimpleSpec):
-            return super().__eq__(other)
-        return self.match(other)
-
-    def __ne__(self, other):
-        return not self.__eq__(other)
-
-    def __hash__(self):
-        return super().__hash__()
-
-
 supported_versions = [
     AsdfVersion("1.0.0"),
     AsdfVersion("1.1.0"),
@@ -154,11 +94,11 @@ supported_versions = [
 ]
 
 
-default_version = AsdfVersion("1.5.0")
+default_version = AsdfVersion("1.6.0")
 
 # This is the ASDF Standard version that is currently in development
 # it is possible that breaking changes will be made to this version.
-asdf_standard_development_version = AsdfVersion("1.6.0")
+asdf_standard_development_version = AsdfVersion("1.7.0")
 
 
 # This is the ASDF Standard version at which the format of the history
@@ -174,3 +114,10 @@ RESTRICTED_KEYS_MIN_VERSION = AsdfVersion("1.6.0")
 # This library never removed defaults for ASDF Standard versions
 # later than 1.5.0, so filling them isn't necessary.
 FILL_DEFAULTS_MAX_VERSION = AsdfVersion("1.5.0")
+
+# ASDF currently only defined a single file format version
+_FILE_FORMAT_VERSION = AsdfVersion("1.0.0")
+
+# ASDF currently only supports a single yaml version
+# use a tuple as that is what yaml expects
+_YAML_VERSION = (1, 1)
